@@ -1,4 +1,4 @@
-VERSION = '2.1.3.1'
+VERSION = '2.1.3.2'
 
 import logging
 import pkgutil
@@ -79,8 +79,8 @@ from pm4py.vis import view_petri_net, save_vis_petri_net, view_dfg, save_vis_dfg
     save_vis_process_tree, \
     view_heuristics_net, save_vis_heuristics_net, view_bpmn, save_vis_bpmn
 from pm4py.filtering import filter_start_activities, filter_end_activities, filter_attribute_values, filter_variants, \
-    filter_variants_percentage, filter_directly_follows_relation, filter_timestamp, filter_trace_attribute, \
-    filter_eventually_follows
+    filter_variants_percentage, filter_directly_follows_relation, filter_time_range, filter_trace_attribute, \
+    filter_eventually_follows_relation, filter_event_attribute_values, filter_trace_attribute_values
 from pm4py.stats import get_start_activities, get_end_activities, get_attributes, get_attribute_values, get_variants, \
     get_trace_attributes
 from pm4py.convert import convert_to_event_log, convert_to_event_stream, convert_to_dataframe, convert_to_bpmn, \
