@@ -1,7 +1,8 @@
+import gzip
 import os
 import sys
 from enum import Enum
-from io import StringIO
+from io import BytesIO
 
 from pm4py.objects.log.log import EventLog, Trace, Event
 from pm4py.objects.log.util import sorting
@@ -16,6 +17,9 @@ class Parameters(Enum):
     MAX_TRACES = "max_traces"
     MAX_BYTES = "max_bytes"
     SKIP_BYTES = "skip_bytes"
+    SET_ATTRIBUTES_TO_READ = "set_attributes_to_read"
+    DECOMPRESS_SERIALIZATION = "decompress_serialization"
+    ENCODING = "encoding"
 
 
 def apply(filename, parameters=None):
@@ -26,7 +30,61 @@ def __fetch_param_value(param, params):
     return params[param] if param in params else param.value
 
 
-def import_log_from_file_object(f, file_size=sys.maxsize, parameters=None):
+def read_attribute_key_value(tag, content, date_parser, values_dict, set_attributes_to_read):
+    """
+    Reads an attribute from the line of the log
+
+    Parameters
+    --------------
+    tag
+        Tag
+    content
+        Full content of the line
+    date_parser
+        Date parser
+    values_dict
+        Dictionary of keys/values already met during the parsing
+    set_attributes_to_read
+        Names of the attributes that should be parsed. If None, then, all the attributes are parsed.
+
+    Returns
+    --------------
+    key
+        Key of the attribute
+    value
+        Value of the attribute
+    """
+    key = content[1]
+    value = None
+
+    if set_attributes_to_read is None or key in set_attributes_to_read:
+        if tag.startswith("string"):
+            value = content[3]
+        elif tag.startswith("date"):
+            value = date_parser.apply(content[3])
+        elif tag.startswith("int"):
+            value = int(content[3])
+        elif tag.startswith("float"):
+            value = float(content[3])
+        else:
+            value = content[3]
+
+        # limits the number of different instantiations of the same key
+        if key in values_dict:
+            key = values_dict[key]
+        else:
+            values_dict[key] = key
+
+        # limits the number of different instantations of the same value
+        if value in values_dict:
+            value = values_dict[value]
+        else:
+            values_dict[value] = value
+
+    return key, value
+
+
+def import_log_from_file_object(f, encoding, file_size=sys.maxsize, parameters=None):
     """
     Import a log object from a (XML) file object
 
@@ -34,6 +92,8 @@ def import_log_from_file_object(f, file_size=sys.maxsize, parameters=None):
     -----------
     f
         file object
+    encoding
+        Encoding
     file_size
         Size of the file (measured on disk)
     parameters
@@ -44,15 +104,18 @@ def import_log_from_file_object(f, file_size=sys.maxsize, parameters=None):
             Parameters.MAX_TRACES -> Specify the maximum number of traces to import from the log (read in order in the XML file)
             Parameters.MAX_BYTES -> Maximum number of bytes to read
             Parameters.SKYP_BYTES -> Number of bytes to skip
-
+            Parameters.SET_ATTRIBUTES_TO_READ -> Names of the attributes that should be parsed. If not specified,
+                                                then, all the attributes are parsed.
 
     Returns
     -----------
     log
         Log file
     """
+    values_dict = {}
     date_parser = dt_parser.get()
 
+    set_attributes_to_read = exec_utils.get_param_value(Parameters.SET_ATTRIBUTES_TO_READ, parameters, None)
     max_no_traces_to_import = exec_utils.get_param_value(Parameters.MAX_TRACES, parameters, sys.maxsize)
     timestamp_sort = exec_utils.get_param_value(Parameters.TIMESTAMP_SORT, parameters, False)
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters,
@@ -73,38 +136,26 @@ def import_log_from_file_object(f, file_size=sys.maxsize, parameters=None):
     f.seek(skip_bytes)
 
     for line in f:
-        content = line.split("\"")
+        content = line.decode(encoding).split("\"")
         if len(content) > 0:
             tag = content[0].split("<")[-1]
             if trace is not None:
                 if event is not None:
                     if len(content) == 5:
-                        if tag.startswith("string"):
-                            event[content[1]] = content[3]
-                        elif tag.startswith("date"):
-                            event[content[1]] = date_parser.apply(content[3])
-                        elif tag.startswith("int"):
-                            event[content[1]] = int(content[3])
-                        elif tag.startswith("float"):
-                            event[content[1]] = float(content[3])
-                        else:
-                            event[content[1]] = content[3]
+                        key, value = read_attribute_key_value(tag, content, date_parser, values_dict,
+                                                              set_attributes_to_read)
+                        if value is not None:
+                            event[key] = value
                     elif tag.startswith("/event"):
                         trace.append(event)
                         event = None
                 elif tag.startswith("event"):
                     event = Event()
                 elif len(content) == 5:
-                    if tag.startswith("string"):
-                        trace.attributes[content[1]] = content[3]
-                    elif tag.startswith("date"):
-                        trace.attributes[content[1]] = date_parser.apply(content[3])
-                    elif tag.startswith("int"):
-                        trace.attributes[content[1]] = int(content[3])
-                    elif tag.startswith("float"):
-                        trace.attributes[content[1]] = float(content[3])
-                    else:
-                        trace.attributes[content[1]] = content[3]
+                    key, value = read_attribute_key_value(tag, content, date_parser, values_dict,
+                                                          set_attributes_to_read)
+                    if value is not None:
+                        trace.attributes[key] = value
                 elif tag.startswith("/trace"):
                     log.append(trace)
                     tracecount += 1
@@ -137,7 +188,9 @@ def import_log(filename, parameters=None):
             Parameters.MAX_TRACES -> Specify the maximum number of traces to import from the log (read in order in the XML file)
             Parameters.MAX_BYTES -> Maximum number of bytes to read
             Parameters.SKYP_BYTES -> Number of bytes to skip
-
+            Parameters.SET_ATTRIBUTES_TO_READ -> Names of the attributes that should be parsed. If not specified,
+                                                then, all the attributes are parsed.
+            Parameters.ENCODING -> Regulates the encoding of the log (default: utf-8)
 
     Returns
     -----------
@@ -147,10 +200,18 @@ def import_log(filename, parameters=None):
     if parameters is None:
         parameters = {}
 
+    encoding = exec_utils.get_param_value(Parameters.ENCODING, parameters, constants.DEFAULT_ENCODING)
+
+    is_compressed = filename.endswith(".gz")
     file_size = os.stat(filename).st_size
 
-    f = open(filename, "r")
-    log = import_log_from_file_object(f, file_size=file_size, parameters=parameters)
+    if is_compressed:
+        f = gzip.open(filename, mode="rb")
+    else:
+        f = open(filename, "rb")
+
+    log = import_log_from_file_object(f, encoding, file_size=file_size, parameters=parameters)
+
     f.close()
 
     return log
@@ -171,6 +232,10 @@ def import_from_string(log_string, parameters=None):
             Parameters.REVERSE_SORT -> Specify in which direction the log should be sorted
             Parameters.INSERT_TRACE_INDICES -> Specify if trace indexes should be added as event attribute for each event
             Parameters.MAX_TRACES -> Specify the maximum number of traces to import from the log (read in order in the XML file)
+            Parameters.DECOMPRESS_SERIALIZATION -> Specify if the string needs to be decompressed during the parsing
+            Parameters.SET_ATTRIBUTES_TO_READ -> Names of the attributes that should be parsed. If not specified,
+                                                then, all the attributes are parsed.
+            Parameters.ENCODING -> Regulates the encoding of the log (default: utf-8)
 
     Returns
     -----------
@@ -180,7 +245,14 @@ def import_from_string(log_string, parameters=None):
     if parameters is None:
         parameters = {}
 
-    if type(log_string) is bytes:
-        log_string = log_string.decode(constants.DEFAULT_ENCODING)
+    encoding = exec_utils.get_param_value(Parameters.ENCODING, parameters, constants.DEFAULT_ENCODING)
 
-    return import_log_from_file_object(StringIO(log_string), parameters=parameters)
+    decompress_serialization = exec_utils.get_param_value(Parameters.DECOMPRESS_SERIALIZATION, parameters, False)
+    b = BytesIO(log_string)
+
+    if decompress_serialization:
+        s = gzip.GzipFile(fileobj=b, mode="rb")
+    else:
+        s = b
+
+    return import_log_from_file_object(s, encoding, parameters=parameters)
