@@ -1,7 +1,7 @@
 from pm4py.util.business_hours import BusinessHours
 from pm4py.objects.log.util import sorting
 from pm4py.util import constants
-from pm4py.objects.log.util import xes
+from pm4py.util import xes_constants as xes
 from pm4py.objects.log.log import EventLog, Trace, Event
 
 
@@ -165,11 +165,7 @@ def assign_lead_cycle_time(log, parameters=None):
     log
         Interval log
     parameters
-        Parameters of the algorithm, including: start_timestamp_key, timestamp_key,
-
-    :param log:
-    :param parameters:
-    :return:
+        Parameters of the algorithm, including: start_timestamp_key, timestamp_key, worktiming, weekends
     """
     if parameters is None:
         parameters = {}
